@@ -30,6 +30,7 @@
 """
 Client for the ID Broker Provisioning API.
 """
+
 import abc
 import datetime
 import json
@@ -64,14 +65,20 @@ from .provisioning_api import (
     WorkgroupsApi as GenWorkGroupsApi,
 )
 
-logger: logging.Logger = lazy_object_proxy.Proxy(lambda: ConsoleAndFileLogging.get_logger(__name__))
+logger: logging.Logger = lazy_object_proxy.Proxy(
+    lambda: ConsoleAndFileLogging.get_logger(__name__)
+)
 _shared_token: Dict[str, "Token"] = {}
 
 GenApiObject = Union[GenSchool, GenSchoolClass, GenSchoolContext, GenUser, GenWorkGroup]
 GenApiHandler = Union[GenSchoolsApi, GenSchoolClassesApi, GenUsersApi, GenWorkGroupsApi]
 IDBrokerObject = Union["School", "SchoolClass", "SchoolContext", "User", "WorkGroup"]
 IDBrokerObjectType = Union[
-    Type["School"], Type["SchoolClass"], Type["SchoolContext"], Type["User"], Type["WorkGroup"]
+    Type["School"],
+    Type["SchoolClass"],
+    Type["SchoolContext"],
+    Type["User"],
+    Type["WorkGroup"],
 ]
 
 ID_BROKER_CLIENT_DEFAULT_TIMEOUT = 180.0
@@ -209,7 +216,8 @@ class SchoolContext(IDBrokerObjectBase):
         return all(
             (
                 {c.lower() for c in self.classes} == {c.lower() for c in other.classes},
-                {w.lower() for w in self.workgroups} == {w.lower() for w in other.workgroups},
+                {w.lower() for w in self.workgroups}
+                == {w.lower() for w in other.workgroups},
                 {r.lower() for r in self.roles} == {r.lower() for r in other.roles},
             )
         )
@@ -220,6 +228,8 @@ class User(IDBrokerObjectBase):
     first_name: str
     last_name: str
     user_name: str
+    legal_guardians: list[str]
+    legal_wards: list[str]
     context: Dict[str, SchoolContext]
     _gen_class = GenUser
 
@@ -232,12 +242,18 @@ class User(IDBrokerObjectBase):
                 self.first_name == other.first_name,
                 self.last_name == other.last_name,
                 self.user_name == other.user_name,
+                (not self.legal_wards and not other.legal_wards)
+                or (set(self.legal_wards) == set(other.legal_wards)),
+                (not self.legal_wards and not other.legal_wards)
+                or (set(self.legal_guardians) == set(other.legal_guardians)),
                 self.context == other.context,
             )
         )
 
     def __repr__(self):
-        return f"{self.__class__.__name__}(user_name={self.user_name!r}, id={self.id!r})"
+        return (
+            f"{self.__class__.__name__}(user_name={self.user_name!r}, id={self.id!r})"
+        )
 
     @classmethod
     def from_gen_obj(cls, gen_obj: GenApiObject) -> "User":
@@ -254,7 +270,9 @@ class User(IDBrokerObjectBase):
         res = super().to_gen_obj()
         res = cast(GenUser, res)
         res.context = {
-            k: GenSchoolContext(classes=v.classes, roles=v.roles, workgroups=v.workgroups)
+            k: GenSchoolContext(
+                classes=v.classes, roles=v.roles, workgroups=v.workgroups
+            )
             for k, v in self.context.items()
         }
         return res
@@ -291,7 +309,9 @@ class Token:
         except jwt.PyJWTError as exc:
             raise ValueError(f"Error decoding token ({access_token!r}): {exc!s}")
         if not isinstance(payload, dict) or "exp" not in payload:
-            raise ValueError(f"Payload in token not a dict or missing 'exp' entry ({access_token!r}).")
+            raise ValueError(
+                f"Payload in token not a dict or missing 'exp' entry ({access_token!r})."
+            )
         try:
             return datetime.datetime.utcfromtimestamp(payload["exp"])
         except ValueError as exc:
@@ -328,9 +348,13 @@ class ProvisioningAPIClient(abc.ABC):
     PROVISIONING_URL_REGEX = r"^https://(?P<host>.+?)/"
     _object_type: IDBrokerObjectType
     _gen_api_handler: Type[GenApiHandler]
-    _share_token = True  # whether all client instances should use the same Token instance
+    _share_token = (
+        True  # whether all client instances should use the same Token instance
+    )
 
-    def __init__(self, school_authority: SchoolAuthorityConfiguration, plugin_name: str):
+    def __init__(
+        self, school_authority: SchoolAuthorityConfiguration, plugin_name: str
+    ):
         self.school_authority = school_authority
         self.plugin_name = plugin_name
         m: Optional[Match] = re.match(self.PROVISIONING_URL_REGEX, school_authority.url)
@@ -344,7 +368,9 @@ class ProvisioningAPIClient(abc.ABC):
         try:
             self.school_authority_name = school_authority.name
             username = school_authority.plugin_configs[plugin_name]["username"]
-            password = school_authority.plugin_configs[plugin_name]["password"].get_secret_value()
+            password = school_authority.plugin_configs[plugin_name][
+                "password"
+            ].get_secret_value()
             version = school_authority.plugin_configs[plugin_name]["version"]
         except KeyError as exc:
             raise ValueError(
@@ -352,12 +378,18 @@ class ProvisioningAPIClient(abc.ABC):
                 f"{school_authority.dict()!r}."
             )
         if version != 1:
-            raise ValueError(f"Unsupported ID Broker Provisioning API version {version!r}.")
-        self.configuration = GenConfiguration(host=target_url, username=username, password=password)
+            raise ValueError(
+                f"Unsupported ID Broker Provisioning API version {version!r}."
+            )
+        self.configuration = GenConfiguration(
+            host=target_url, username=username, password=password
+        )
         http_proxy = os.environ.get("http_proxy") or os.environ.get("HTTP_PROXY")
         https_proxy = os.environ.get("https_proxy") or os.environ.get("HTTPS_PROXY")
         if https_proxy and not http_proxy:
-            logger.warning("Environment variabel HTTPS_PROXY not supported. Use HTTP_PROXY instead.")
+            logger.warning(
+                "Environment variabel HTTPS_PROXY not supported. Use HTTP_PROXY instead."
+            )
         self.configuration.proxy = http_proxy
         self.configuration.verify_ssl = "UNSAFE_SSL" not in os.environ
         if not self.configuration.verify_ssl:
@@ -443,10 +475,14 @@ class ProvisioningAPIClient(abc.ABC):
         """
         request_id = uuid.uuid4().hex
         _request_id = request_id[:10]
-        logger.debug("[%s] Deleting %s %r...", _request_id, self._object_type.__name__, obj_id)
+        logger.debug(
+            "[%s] Deleting %s %r...", _request_id, self._object_type.__name__, obj_id
+        )
         try:
             await self._request("delete", id=obj_id, request_id=request_id, **kwargs)
-            logger.debug("[%s] %s %r deleted.", _request_id, self._object_type.__name__, obj_id)
+            logger.debug(
+                "[%s] %s %r deleted.", _request_id, self._object_type.__name__, obj_id
+            )
         except ApiException as exc:
             if exc.status != 404:
                 raise IDBrokerError(
@@ -469,11 +505,16 @@ class ProvisioningAPIClient(abc.ABC):
         request_id = uuid.uuid4().hex
         _request_id = request_id[:10]
         logger.debug(
-            "[%s] Checking existence of %s %r...", _request_id, self._object_type.__name__, obj_id
+            "[%s] Checking existence of %s %r...",
+            _request_id,
+            self._object_type.__name__,
+            obj_id,
         )
         try:
             await self._request("head", id=obj_id, request_id=request_id, **kwargs)
-            logger.debug("[%s] %s %r exists.", _request_id, self._object_type.__name__, obj_id)
+            logger.debug(
+                "[%s] %s %r exists.", _request_id, self._object_type.__name__, obj_id
+            )
         except ApiException as exc:
             if exc.status != 404:
                 raise IDBrokerError(
@@ -481,7 +522,12 @@ class ProvisioningAPIClient(abc.ABC):
                     f"[{_request_id}] Error HTTP {exc.status} ({exc.reason}) checking existence of "
                     f"{self._object_type.__name__} using {kwargs!r}.",
                 )
-            logger.debug("[%s] %s %r does not exist.", _request_id, self._object_type.__name__, obj_id)
+            logger.debug(
+                "[%s] %s %r does not exist.",
+                _request_id,
+                self._object_type.__name__,
+                obj_id,
+            )
             return False
         return True
 
@@ -554,7 +600,9 @@ class ProvisioningAPIClient(abc.ABC):
             )
         return new_obj
 
-    async def _request(self, method: str, request_id: str, *args, **kwargs) -> Optional[IDBrokerObject]:
+    async def _request(
+        self, method: str, request_id: str, *args, **kwargs
+    ) -> Optional[IDBrokerObject]:
         self.configuration.access_token = await self.token.access_token
         if "_request_timeout" not in kwargs:
             kwargs["_request_timeout"] = ID_BROKER_CLIENT_DEFAULT_TIMEOUT
@@ -598,11 +646,15 @@ class IDBrokerUser(ProvisioningAPIClient):
 
     async def exists(self, obj_id: str) -> bool:
         """Check if the user with the ID `obj_id` exists on the server."""
-        return await self._exists(obj_id=obj_id, school_authority=self.school_authority_name)
+        return await self._exists(
+            obj_id=obj_id, school_authority=self.school_authority_name
+        )
 
     async def get(self, obj_id: str) -> User:
         """Retrieve user with ID `obj_id` from the server."""
-        res = await super()._get(obj_id=obj_id, school_authority=self.school_authority_name)
+        res = await super()._get(
+            obj_id=obj_id, school_authority=self.school_authority_name
+        )
         return self._sorted_context_lists(cast(User, res))
 
     async def update(self, user: User) -> User:
@@ -645,16 +697,22 @@ class IDBrokerSchool(ProvisioningAPIClient):
 
     async def exists(self, obj_id: str) -> bool:
         """Check if school with ID `obj_id` exists on the server."""
-        return await self._exists(obj_id=obj_id, school_authority=self.school_authority_name)
+        return await self._exists(
+            obj_id=obj_id, school_authority=self.school_authority_name
+        )
 
     async def get(self, obj_id: str) -> School:
         """Retrieve school with ID `obj_id` from the server."""
-        res = await super()._get(obj_id=obj_id, school_authority=self.school_authority_name)
+        res = await super()._get(
+            obj_id=obj_id, school_authority=self.school_authority_name
+        )
         return cast(School, res)
 
     async def delete(self, obj_id: str) -> None:
         """Delete school with ID `obj_id` from the server."""
-        await super()._delete(obj_id=obj_id, school_authority=self.school_authority_name)
+        await super()._delete(
+            obj_id=obj_id, school_authority=self.school_authority_name
+        )
 
 
 class IDBrokerSchoolClass(ProvisioningAPIClient):
@@ -679,11 +737,15 @@ class IDBrokerSchoolClass(ProvisioningAPIClient):
 
     async def exists(self, obj_id: str) -> bool:
         """Check if the school class with the ID `obj_id` exists on the server."""
-        return await self._exists(obj_id=obj_id, school_authority=self.school_authority_name)
+        return await self._exists(
+            obj_id=obj_id, school_authority=self.school_authority_name
+        )
 
     async def get(self, obj_id: str) -> SchoolClass:
         """Retrieve school class with ID `obj_id` from the server."""
-        res = await super()._get(obj_id=obj_id, school_authority=self.school_authority_name)
+        res = await super()._get(
+            obj_id=obj_id, school_authority=self.school_authority_name
+        )
         return self._sorted_members(cast(SchoolClass, res))
 
     async def update(self, school_class: SchoolClass) -> SchoolClass:
@@ -728,11 +790,15 @@ class IDBrokerWorkGroup(ProvisioningAPIClient):
 
     async def exists(self, obj_id: str) -> bool:
         """Check if the work group with the ID `obj_id` exists on the server."""
-        return await self._exists(obj_id=obj_id, school_authority=self.school_authority_name)
+        return await self._exists(
+            obj_id=obj_id, school_authority=self.school_authority_name
+        )
 
     async def get(self, obj_id: str) -> WorkGroup:
         """Retrieve work group with ID `obj_id` from the server."""
-        res = await super()._get(obj_id=obj_id, school_authority=self.school_authority_name)
+        res = await super()._get(
+            obj_id=obj_id, school_authority=self.school_authority_name
+        )
         return self._sorted_members(cast(WorkGroup, res))
 
     async def update(self, work_group: WorkGroup) -> WorkGroup:
