@@ -41,7 +41,11 @@ import click
 from fastapi import HTTPException
 
 try:
-    from idbroker.config_utils import CONFIG_PATH, NoConfigFoundError, read_id_broker_config
+    from idbroker.config_utils import (
+        CONFIG_PATH,
+        NoConfigFoundError,
+        read_id_broker_config,
+    )
     from idbroker.id_broker_client import IDBrokerSchool
     from idbroker.initial_sync import get_ous, setup, sync_complete
     from idbroker.utils import get_configured_schools, school_in_configured_schools
@@ -71,8 +75,7 @@ from ucsschool_id_connector.school_scheduler import SchoolScheduler
 from ucsschool_id_connector.utils import ConsoleAndFileLogging
 
 
-class ManageSchoolsException(Exception):
-    ...
+class ManageSchoolsException(Exception): ...
 
 
 class ManageSchoolsOnIDBroker:
@@ -124,7 +127,9 @@ class ManageSchoolsOnIDBroker:
     async def restore_old_config(self, old_config: SchoolAuthorityConfiguration):
         config = old_config.dict_secrets_as_str()
         try:
-            await self.patch_school_authority_config(data={"plugin_configs": config["plugin_configs"]})
+            await self.patch_school_authority_config(
+                data={"plugin_configs": config["plugin_configs"]}
+            )
         except ManageSchoolsException:
             self.logger.error(
                 "Failed to restore settings via HTTP API. Restoring manually."
@@ -156,12 +161,18 @@ class ManageSchoolsOnIDBroker:
         patch_data = SchoolAuthorityConfigurationPatchDocument(**data)
         try:
             res = await query_service(
-                cmd="patch_school_authority", name=self.school_authority, school_authority=patch_data
+                cmd="patch_school_authority",
+                name=self.school_authority,
+                school_authority=patch_data,
             )
             if res.get("errors"):
-                raise ManageSchoolsException(f"Error while trying to patch the school authority: {res}")
+                raise ManageSchoolsException(
+                    f"Error while trying to patch the school authority: {res}"
+                )
         except HTTPException as e:
-            raise ManageSchoolsException(f"Error while trying to patch the school authority: {e!r}")
+            raise ManageSchoolsException(
+                f"Error while trying to patch the school authority: {e!r}"
+            )
 
     async def set_initial_sync_mode(self, value: bool):
         patch_data = {"plugin_configs": {"id_broker": {"initial_import_mode": value}}}
@@ -186,7 +197,9 @@ class ManageSchoolsOnIDBroker:
                     "Or temporarily add the school to ensure you keep a valid configuration."
                 )
             else:
-                self.logger.info(f"School {school} was already removed from configuration.")
+                self.logger.info(
+                    f"School {school} was already removed from configuration."
+                )
                 return
         schools = [s for s in schools if s.lower() != school.lower()]
         patch_data = {"plugin_configs": {"id_broker": {"schools": schools}}}
@@ -236,16 +249,22 @@ class ManageSchoolsOnIDBroker:
                     )
 
                 self.logger.info(f"Connect school {school} to the ID Broker.")
-                self.logger.info(f"Adding {school} to the schools which are synced to the ID Broker.")
+                self.logger.info(
+                    f"Adding {school} to the schools which are synced to the ID Broker."
+                )
                 self.check_config_is_active_for_initial_sync()
                 await self.add_school_to_config(school=school)
                 await self.set_initial_sync_mode(value=True)
                 setup(config_path=CONFIG_PATH)
                 for ldap_school in ldap_schools:
                     if ldap_school.name in synced_schools:
-                        self.logger.info(f"School {ldap_school.name} has already been synced this run.")
+                        self.logger.info(
+                            f"School {ldap_school.name} has already been synced this run."
+                        )
                         continue
-                    self.logger.info(f"Sync groups of school {ldap_school.name} (without members).")
+                    self.logger.info(
+                        f"Sync groups of school {ldap_school.name} (without members)."
+                    )
                     await sync_complete(
                         school=ldap_school.name,
                         dry_run=False,
@@ -263,7 +282,9 @@ class ManageSchoolsOnIDBroker:
                         f"Waiting until all users of {ldap_school.name} are synced. This will take a while."
                     )
                     await self.wait_for_empty_queue()
-                    self.logger.info(f"Update group memberships of school {ldap_school.name}.")
+                    self.logger.info(
+                        f"Update group memberships of school {ldap_school.name}."
+                    )
                     await sync_complete(
                         school=ldap_school.name,
                         dry_run=False,
@@ -304,19 +325,25 @@ class ManageSchoolsOnIDBroker:
         ldap_schools = await get_ous(school_filter)
         if not ldap_schools:
             # We need the school id to be able to delete the school.
-            self.logger.error(f"School {school_filter} does not exist on the ID Broker.")
+            self.logger.error(
+                f"School {school_filter} does not exist on the ID Broker."
+            )
             sys.exit(1)
 
         configured_schools = get_configured_schools(self.get_config())
         for ldap_school in ldap_schools:
-            if school_in_configured_schools(ldap_school.name.lower(), configured_schools):
+            if school_in_configured_schools(
+                ldap_school.name.lower(), configured_schools
+            ):
                 # This can happend in in combination with wildcards
                 self.logger.warning(
                     f"School {ldap_school.name} is still configured and will not be deleted."
                 )
                 continue
             await school_client.delete(ldap_school.id)
-            end = datetime.datetime.now() + datetime.timedelta(seconds=self.wait_school_deletion_timeout)
+            end = datetime.datetime.now() + datetime.timedelta(
+                seconds=self.wait_school_deletion_timeout
+            )
             while True:
                 school_exists = await school_client.exists(ldap_school.id)
                 if school_exists is False:
@@ -368,10 +395,16 @@ def manage_schools_cli():
 )
 @click.argument("schools", required=False, nargs=-1)
 def remove_schools(
-    schools: List[str], school_authority: str, force: bool, all_schools: bool, delete_schools: bool
+    schools: List[str],
+    school_authority: str,
+    force: bool,
+    all_schools: bool,
+    delete_schools: bool,
 ):
     logger = ConsoleAndFileLogging.get_logger(__name__)
-    manager = ManageSchoolsOnIDBroker(school_authority=school_authority, logger=logger, force=force)
+    manager = ManageSchoolsOnIDBroker(
+        school_authority=school_authority, logger=logger, force=force
+    )
     if not all_schools and not schools:
         logger.error("Missing positional argument schools or --all_schools option.")
         sys.exit(1)
@@ -395,7 +428,9 @@ def remove_schools(
             error_msg = "Aborted"
         else:
             error_msg = str(exc)
-        logger.error(f"An error was raised while trying to remove the schools: {error_msg}")
+        logger.error(
+            f"An error was raised while trying to remove the schools: {error_msg}"
+        )
         sys.exit(1)
 
 
@@ -478,7 +513,9 @@ def add_schools(
             error_msg = "Aborted"
         else:
             error_msg = str(exc)
-        logger.error(f"An error was raised while trying to add the schools: {error_msg}")
+        logger.error(
+            f"An error was raised while trying to add the schools: {error_msg}"
+        )
         sys.exit(1)
 
 
