@@ -96,6 +96,8 @@ async def to_id_broker_user_without_groups(
                 classes=[], workgroups=[], roles=user["roles"]
             )
         },
+        legal_wards=user.get("legal_wards", []),
+        legal_guardians=user.get("legal_guardians", []),
     )
 
 
