@@ -30,7 +30,12 @@ import os.path
 import subprocess
 
 import pytest
-from tenacity import AsyncRetrying, retry_if_exception_type, stop_after_attempt, wait_fixed
+from tenacity import (
+    AsyncRetrying,
+    retry_if_exception_type,
+    stop_after_attempt,
+    wait_fixed,
+)
 
 import ucsschool_id_connector.plugin_loader
 
@@ -75,7 +80,9 @@ async def test_add_schools(
     elif schools_arg == "school_name":
         school_filter = [kelvin_school_on_sender.name]
     elif schools_arg == "partial_school_name":
-        school_filter = [f"{kelvin_school_on_sender.name[0]}*{kelvin_school_on_sender.name[2:]}"]
+        school_filter = [
+            f"{kelvin_school_on_sender.name[0]}*{kelvin_school_on_sender.name[2:]}"
+        ]
     elif schools_arg == "*":
         school_filter = ["*"]
     else:
@@ -108,7 +115,9 @@ async def test_add_schools(
         school=kelvin_school_on_sender.name,
         name=work_group.name,
     )
-    await delete_school_on_id_broker(config=school_authority, schools=[kelvin_school_on_sender.name])
+    await delete_school_on_id_broker(
+        config=school_authority, schools=[kelvin_school_on_sender.name]
+    )
     await wait_for_kelvin_user_on_id_broker(
         s_a_name=school_authority.name,
         school=kelvin_school_on_sender.name,
@@ -140,7 +149,9 @@ async def test_add_schools(
     elif schools_arg == "school_name":
         add_school_args.append(kelvin_school_on_sender.name)
     elif schools_arg == "partial_school_name":
-        add_school_args.append(f"{kelvin_school_on_sender.name[0]}*{kelvin_school_on_sender.name[2:]}")
+        add_school_args.append(
+            f"{kelvin_school_on_sender.name[0]}*{kelvin_school_on_sender.name[2:]}"
+        )
     elif schools_arg == "*":
         add_school_args.append("*")
     else:
@@ -156,7 +167,9 @@ async def test_add_schools(
     )
     print(output)
     await wait_for_kelvin_user_on_id_broker(
-        s_a_name=school_authority.name, school=kelvin_school_on_sender.name, name=sender_user["name"]
+        s_a_name=school_authority.name,
+        school=kelvin_school_on_sender.name,
+        name=sender_user["name"],
     )
     async for attempt in AsyncRetrying(
         reraise=True,
@@ -179,7 +192,9 @@ async def test_add_schools(
     assert wg.users == [f"{school_authority.name}-{sender_user['name']}"]
     with open(os.path.join(SCHOOL_CONFIG_PATH, f"{school_authority.name}.json")) as fin:
         config = json.load(fin)
-        assert sorted(school_filter) == sorted(config["plugin_configs"]["id_broker"]["schools"])
+        assert sorted(school_filter) == sorted(
+            config["plugin_configs"]["id_broker"]["schools"]
+        )
 
 
 @pytest.mark.asyncio
@@ -206,7 +221,9 @@ async def test_remove_schools(
     elif schools_arg == "school_name":
         school_filter = [kelvin_school_on_sender.name]
     elif schools_arg == "partial_school_name":
-        school_filter = [f"{kelvin_school_on_sender.name[0]}*{kelvin_school_on_sender.name[2:]}"]
+        school_filter = [
+            f"{kelvin_school_on_sender.name[0]}*{kelvin_school_on_sender.name[2:]}"
+        ]
     elif schools_arg == "*":
         school_filter = ["*"]
     else:
@@ -215,7 +232,9 @@ async def test_remove_schools(
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
-    work_group = await make_kelvin_workgroup_on_id_connector(school_name=kelvin_school_on_sender.name)
+    work_group = await make_kelvin_workgroup_on_id_connector(
+        school_name=kelvin_school_on_sender.name
+    )
     await wait_for_kelvin_workgroup_on_id_broker(
         s_a_name=school_authority.name,
         school=kelvin_school_on_sender.name,
@@ -225,7 +244,9 @@ async def test_remove_schools(
         ous=[kelvin_school_on_sender.name],
     )
     await wait_for_kelvin_user_on_id_broker(
-        s_a_name=school_authority.name, school=kelvin_school_on_sender.name, name=user["name"]
+        s_a_name=school_authority.name,
+        school=kelvin_school_on_sender.name,
+        name=user["name"],
     )
     school_class = await make_kelvin_school_class_on_id_connector(
         school_name=kelvin_school_on_sender.name, users=[user["name"]]
@@ -296,7 +317,9 @@ async def test_remove_schools_skip_configured(
     schedule_schools_delete,
 ):
     school1, school2 = await kelvin_schools_on_sender(2)
-    school_authority = await set_school_authority_on_id_connector(schools=[school1.name, "*"])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[school1.name, "*"]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[school1.name, school2.name]
     )
@@ -354,11 +377,15 @@ async def test_remove_schools_dont_remove_schools_on_id_broker(
     schedule_schools_delete,
     set_school_authority_on_id_connector,
 ):
-    school_authority = await set_school_authority_on_id_connector(schools=[kelvin_school_on_sender.name])
+    school_authority = await set_school_authority_on_id_connector(
+        schools=[kelvin_school_on_sender.name]
+    )
     await schedule_schools_delete(
         school_authority=school_authority, schools=[kelvin_school_on_sender.name]
     )
-    work_group = await make_kelvin_workgroup_on_id_connector(school_name=kelvin_school_on_sender.name)
+    work_group = await make_kelvin_workgroup_on_id_connector(
+        school_name=kelvin_school_on_sender.name
+    )
     user = await make_sender_user_special(
         ous=[kelvin_school_on_sender.name],
     )
@@ -366,7 +393,9 @@ async def test_remove_schools_dont_remove_schools_on_id_broker(
         school_name=kelvin_school_on_sender.name, users=[user["name"]]
     )
     await wait_for_kelvin_user_on_id_broker(
-        s_a_name=school_authority.name, school=kelvin_school_on_sender.name, name=user["name"]
+        s_a_name=school_authority.name,
+        school=kelvin_school_on_sender.name,
+        name=user["name"],
     )
     await wait_for_kelvin_school_class_on_id_broker(
         s_a_name=school_authority.name,
@@ -406,7 +435,10 @@ async def test_remove_schools_dont_remove_schools_on_id_broker(
     )
     with open(os.path.join(SCHOOL_CONFIG_PATH, f"{school_authority.name}.json")) as fin:
         config = json.load(fin)
-        assert kelvin_school_on_sender.name not in config["plugin_configs"]["id_broker"]["schools"]
+        assert (
+            kelvin_school_on_sender.name
+            not in config["plugin_configs"]["id_broker"]["schools"]
+        )
 
 
 @pytest.mark.asyncio
@@ -448,9 +480,13 @@ async def test_configure_schools(
     with open(os.path.join(SCHOOL_CONFIG_PATH, f"{school_authority.name}.json")) as fin:
         config = json.load(fin)
         if all_schools:
-            assert set(schools_on_sender) == set(config["plugin_configs"]["id_broker"]["schools"])
+            assert set(schools_on_sender) == set(
+                config["plugin_configs"]["id_broker"]["schools"]
+            )
         else:
-            assert [kelvin_school_on_sender.name] == config["plugin_configs"]["id_broker"]["schools"]
+            assert [kelvin_school_on_sender.name] == config["plugin_configs"][
+                "id_broker"
+            ]["schools"]
     # -> should fail, because there we try to add the same schools again.
     with pytest.raises(subprocess.CalledProcessError):
         subprocess.check_call(configure_all_school_args)
