@@ -134,7 +134,7 @@ def extract_members(group: SddbGroup, service_provider: str) -> GroupMembers:
                 lastname=redis_internal_student["data"]["lastname"],
                 legal_guardians=convert_pks_to_basic_users(
                     group.pseudonym,
-                    redis_internal_student["legal_guardians"],
+                    redis_internal_student.get("legal_guardians", []),
                     service_provider,
                 ),
             )
@@ -178,7 +178,7 @@ def extract_members(group: SddbGroup, service_provider: str) -> GroupMembers:
                 lastname=redis_internal_legal_guardian["data"]["lastname"],
                 legal_wards=convert_pks_to_basic_users(
                     group.pseudonym,
-                    redis_internal_legal_guardian["legal_wards"],
+                    redis_internal_legal_guardian.get("legal_wards", []),
                     service_provider,
                 ),
             )
