@@ -24,7 +24,9 @@ def selenium() -> webdriver.Chrome:
     Browser based testing for using Selenium.
     """
     chrome_options = webdriver.ChromeOptions()
-    chrome_options.add_argument("--no-sandbox")  # chrome complains about being executed as root
+    chrome_options.add_argument(
+        "--no-sandbox"
+    )  # chrome complains about being executed as root
     chrome_options.add_argument("ignore-certificate-errors")
     driver = webdriver.Chrome(options=chrome_options)
     return driver
