@@ -33,8 +33,12 @@ def test_failure_count(check_failure_count, run_test):
 
 
 def test_rps(check_rps, run_test):
-    check_rps(RESULT_FILE_BASE_PATH, URL_NAME, 0.1)  # TODO: set desired target performance
+    check_rps(
+        RESULT_FILE_BASE_PATH, URL_NAME, 0.1
+    )  # TODO: set desired target performance
 
 
 def test_95_percentile(check_95_percentile, run_test):
-    check_95_percentile(RESULT_FILE_BASE_PATH, URL_NAME, 10000)  # TODO: set desired target performance
+    check_95_percentile(
+        RESULT_FILE_BASE_PATH, URL_NAME, 10000
+    )  # TODO: set desired target performance
