@@ -10,12 +10,14 @@ DEFAULT_SCHOOL_NAME = "School1"
 EXPECTED_HEADER_NAME = "X-Request-ID"
 
 must_run_in_docker = pytest.mark.skipif(
-    "DOCKER_HOST_NAME" not in os.environ, reason="Integration tests should only run in container"
+    "DOCKER_HOST_NAME" not in os.environ,
+    reason="Integration tests should only run in container",
 )
 
 
 def get_access_token(
-    username: str = f"provisioning-{DEFAULT_SCHOOL_AUTHORITY}", password: str = DEFAULT_PASSWORD
+    username: str = f"provisioning-{DEFAULT_SCHOOL_AUTHORITY}",
+    password: str = DEFAULT_PASSWORD,
 ) -> str:
     response = requests.post(
         url=f"http://{os.environ['DOCKER_HOST_NAME']}/ucsschool/apis/auth/token",
