@@ -2,7 +2,15 @@ import pytest
 from pydantic import ValidationError
 
 import provisioning_plugin.models
-from provisioning_plugin.models import School, SchoolClass, SchoolContext, User, WorkGroup
+from provisioning_plugin.models import (
+    School,
+    SchoolClass,
+    SchoolContext,
+    User,
+    WorkGroup,
+)
+from tests.integration_tests.utils import DEFAULT_SCHOOL_AUTHORITY
+from ucsschool.kelvin.client import User as KelvinUser
 
 
 @pytest.fixture()
@@ -13,7 +21,9 @@ def reference_user():
         last_name="Mustermann",
         user_name="max.m",
         context={
-            "School1": SchoolContext(roles={"teacher"}, classes={"1a"}, workgroups={"Wg1"}),
+            "School1": SchoolContext(
+                roles={"teacher"}, classes={"1a"}, workgroups={"Wg1"}
+            ),
             "School2": SchoolContext(roles={"teacher"}, classes={"2b", "3c"}),
         },
     )
@@ -43,11 +53,19 @@ def reference_workgroup():
 
 def test_user_empty_context():
     with pytest.raises(ValidationError, match="The context must not be empty!"):
-        User(id="m.m", first_name="Max", last_name="Mustermann", user_name="max.m", context={})
+        User(
+            id="m.m",
+            first_name="Max",
+            last_name="Mustermann",
+            user_name="max.m",
+            context={},
+        )
 
 
 def test_user_non_uniform_roles():
-    with pytest.raises(ValidationError, match="All schools must have the same set of roles!"):
+    with pytest.raises(
+        ValidationError, match="All schools must have the same set of roles!"
+    ):
         User(
             id="m.m",
             first_name="Max",
@@ -60,19 +78,28 @@ def test_user_non_uniform_roles():
         )
 
 
-def test_user_from_kelvin_user(reference_user):
+@pytest.mark.asyncio
+async def test_user_from_kelvin_user(reference_user):
+    prefix = f"{DEFAULT_SCHOOL_AUTHORITY}-"
+    school1 = f"{prefix}School1"
+    school2 = f"{prefix}School2"
     assert (
-        User.from_kelvin_user(
-            {
-                "record_uid": "m.m",
-                "firstname": "Max",
-                "lastname": "Mustermann",
-                "name": "max.m",
-                "schools": ["School1", "School2"],
-                "school_classes": {"School1": ["1a"], "School2": ["2b", "3c"]},
-                "workgroups": {"School1": ["Wg1"], "School2": []},
-                "ucsschool_roles": ["teacher:school:School1", "teacher:school:School2"],
-            }
+        await User.from_kelvin_user(
+            KelvinUser(
+                record_uid="m.m",
+                firstname="Max",
+                lastname="Mustermann",
+                name=f"{prefix}max.m",
+                schools=[school1, school2],
+                school_classes={school1: ["1a"], school2: ["2b", "3c"]},
+                workgroups={school1: ["Wg1"], school2: []},
+                ucsschool_roles=[
+                    f"teacher:school:{school1}",
+                    f"teacher:school:{school2}",
+                ],
+                roles=["teacher"],
+            ),
+            DEFAULT_SCHOOL_AUTHORITY,
         )
         == reference_user
     )
@@ -103,41 +130,13 @@ def test_user_prop_school(reference_user):
     assert reference_user.school == "School1"
 
 
-def test_user_without_prefix(reference_user):
-    assert (
-        User.without_prefix(
-            User(
-                id="m.m",
-                first_name="Max",
-                last_name="Mustermann",
-                user_name="TEST-max.m",
-                context={
-                    "TEST-School1": SchoolContext(roles={"teacher"}, classes={"1a"}, workgroups={"Wg1"}),
-                    "TEST-School2": SchoolContext(roles={"teacher"}, classes={"2b", "3c"}),
-                },
-            ),
-            "TEST",
-        )
-        == reference_user
-    )
-
-
-def test_user_with_prefix(reference_user):
-    assert User.with_prefix(reference_user, "TEST") == User(
-        id="m.m",
-        first_name="Max",
-        last_name="Mustermann",
-        user_name="TEST-max.m",
-        context={
-            "TEST-School1": SchoolContext(roles={"teacher"}, classes={"1a"}, workgroups={"Wg1"}),
-            "TEST-School2": SchoolContext(roles={"teacher"}, classes={"2b", "3c"}, workgroups=set()),
-        },
-    )
-
-
 def test_school_from_kelvin_school():
     assert School.from_kelvin_school(
-        dict(name="TEST", display_name="Display Test", udm_properties={"ucsschoolRecordUID": "TEST_ID"})
+        dict(
+            name="TEST",
+            display_name="Display Test",
+            udm_properties={"ucsschoolRecordUID": "TEST_ID"},
+        )
     ) == School(name="TEST", display_name="Display Test", id="TEST_ID")
 
 
@@ -148,20 +147,26 @@ def test_school_without_prefix():
 
 
 def test_school_with_prefix():
-    assert School.with_prefix(School(name="S1", display_name="S1", id="TEST_ID"), "TEST") == School(
-        name="TEST-S1", display_name="S1", id="TEST_ID"
-    )
+    assert School.with_prefix(
+        School(name="S1", display_name="S1", id="TEST_ID"), "TEST"
+    ) == School(name="TEST-S1", display_name="S1", id="TEST_ID")
 
 
 @pytest.mark.asyncio
-async def test_school_class_from_kelvin_school_class(mocker, monkeypatch, reference_school_class):
+async def test_school_class_from_kelvin_school_class(
+    mocker, monkeypatch, reference_school_class
+):
     async def retrieve_users_in_parallel_mock(user_names, *, parallelism, session):
         return [mocker.Mock(record_uid=f"{user_name}-id") for user_name in user_names]
 
     monkeypatch.setattr(
-        provisioning_plugin.models, "retrieve_users_in_parallel", retrieve_users_in_parallel_mock
+        provisioning_plugin.models,
+        "retrieve_users_in_parallel",
+        retrieve_users_in_parallel_mock,
+    )
+    mocker.patch(
+        "provisioning_plugin.models.kelvin_access_parallelism_setting", return_value=4
     )
-    mocker.patch("provisioning_plugin.models.kelvin_access_parallelism_setting", return_value=4)
     assert (
         await SchoolClass.from_kelvin_school_class(
             {
@@ -178,14 +183,20 @@ async def test_school_class_from_kelvin_school_class(mocker, monkeypatch, refere
 
 
 @pytest.mark.asyncio
-async def test_workgroup_from_kelvin_workgroup(mocker, monkeypatch, reference_workgroup):
+async def test_workgroup_from_kelvin_workgroup(
+    mocker, monkeypatch, reference_workgroup
+):
     async def retrieve_users_in_parallel_mock(user_names, *, parallelism, session):
         return [mocker.Mock(record_uid=f"{user_name}-id") for user_name in user_names]
 
     monkeypatch.setattr(
-        provisioning_plugin.models, "retrieve_users_in_parallel", retrieve_users_in_parallel_mock
+        provisioning_plugin.models,
+        "retrieve_users_in_parallel",
+        retrieve_users_in_parallel_mock,
+    )
+    mocker.patch(
+        "provisioning_plugin.models.kelvin_access_parallelism_setting", return_value=4
     )
-    mocker.patch("provisioning_plugin.models.kelvin_access_parallelism_setting", return_value=4)
     assert (
         await WorkGroup.from_kelvin_workgroup(
             {
@@ -202,7 +213,9 @@ async def test_workgroup_from_kelvin_workgroup(mocker, monkeypatch, reference_wo
 
 
 @pytest.mark.asyncio
-async def test_workgroup_from_kelvin_workgroup_no_fill_members(mocker, reference_workgroup):
+async def test_workgroup_from_kelvin_workgroup_no_fill_members(
+    mocker, reference_workgroup
+):
     wg = reference_workgroup
     wg.members = set()
     assert (
